@@ -13,6 +13,7 @@ import uuid
 
 from .config import ServerParameter, ServerConfigManager
 from .utils import get_data_dir
+from .streaming import MCPStreamWrapper, OpenAIStreamFormatter
 
 
 class BaseMCPServer(ABC):
@@ -32,18 +33,21 @@ class BaseMCPServer(ABC):
         # 服务器运行时配置
         self.server_config: Dict[str, Any] = {}
 
-        # 添加配置管理器
-        self.server_config_manager = ServerConfigManager(name)
+        # 注意：不在这里创建配置管理器，因为它应该由启动器根据端口创建
+        # 这避免了创建没有端口号的默认配置文件
+        self.server_config_manager = None
 
         # 流式停止管理
         self._streaming_sessions: Set[str] = set()  # 活跃的流式会话ID
         self._stop_streaming: bool = False  # 全局停止标志
         self._session_stop_flags: Dict[str, bool] = {}  # 单个会话停止标志
 
-        # 尝试加载已保存的配置
-        saved_config = self.server_config_manager.load_server_config()
-        if saved_config:
-            self.configure_server(saved_config)
+        # 配置更新回调机制
+        self._config_update_callbacks: List[Callable[[Dict[str, Any], Dict[str, Any]], None]] = []
+        
+        # OpenAI 格式流式包装器
+        self._openai_stream_wrapper = MCPStreamWrapper(model_name=f"{name}-{version}")
+        self._enable_openai_format = True  # 默认启用OpenAI格式
 
     @abstractmethod
     async def initialize(self) -> None:
@@ -55,10 +59,9 @@ class BaseMCPServer(ABC):
         """处理工具调用，子类必须实现"""
         pass
 
-    @abstractmethod
     def get_server_parameters(self) -> List[ServerParameter]:
-        """获取服务器配置参数定义，子类必须实现"""
-        pass
+        """获取服务器配置参数定义，子类可以重写"""
+        return []
 
     async def handle_resource_request(self, uri: str) -> Dict[str, Any]:
         """处理资源请求，子类可以重写"""
@@ -328,6 +331,9 @@ class BaseMCPServer(ABC):
     def configure_server(self, config: Dict[str, Any]) -> bool:
         """配置服务器参数"""
         try:
+            # 保存旧配置用于回调通知
+            old_config = self.server_config.copy()
+            
             # 验证配置参数
             parameters = self.get_server_parameters()
             param_dict = {p.name: p for p in parameters}
@@ -359,6 +365,10 @@ class BaseMCPServer(ABC):
             # 保存配置
             if self.server_config_manager.save_server_config(self.server_config):
                 self.logger.info(f"Server configured and saved: {self.server_config}")
+                
+                # 通知配置更新回调
+                self._notify_config_update(old_config, self.server_config.copy())
+                
                 return True
             else:
                 self.logger.error("Failed to save server configuration")
@@ -372,6 +382,118 @@ class BaseMCPServer(ABC):
         """获取配置值"""
         return self.server_config.get(key, default)
 
+    def register_config_update_callback(self, callback: Callable[[Dict[str, Any], Dict[str, Any]], None]) -> None:
+        """注册配置更新回调函数
+        
+        Args:
+            callback: 回调函数，接收两个参数：(old_config, new_config)
+        """
+        if callback not in self._config_update_callbacks:
+            self._config_update_callbacks.append(callback)
+            self.logger.info(f"Registered config update callback: {callback.__name__}")
+
+    def unregister_config_update_callback(self, callback: Callable[[Dict[str, Any], Dict[str, Any]], None]) -> None:
+        """取消注册配置更新回调函数"""
+        if callback in self._config_update_callbacks:
+            self._config_update_callbacks.remove(callback)
+            self.logger.info(f"Unregistered config update callback: {callback.__name__}")
+    
+    def set_openai_format_enabled(self, enabled: bool) -> None:
+        """设置是否启用OpenAI格式的流式返回"""
+        self._enable_openai_format = enabled
+        self.logger.info(f"OpenAI format streaming {'enabled' if enabled else 'disabled'}")
+    
+    def is_openai_format_enabled(self) -> bool:
+        """检查是否启用了OpenAI格式的流式返回"""
+        return self._enable_openai_format
+    
+    async def handle_tool_call_stream_openai(
+        self, 
+        tool_name: str, 
+        arguments: Dict[str, Any], 
+        session_id: str = None
+    ) -> AsyncGenerator[str, None]:
+        """处理工具调用并返回OpenAI格式的流式数据
+        
+        Args:
+            tool_name: 工具名称
+            arguments: 工具参数
+            session_id: 会话ID，如果为None则自动创建
+            
+        Yields:
+            OpenAI格式的SSE数据字符串
+        """
+        if not self._enable_openai_format:
+            # 如果未启用OpenAI格式，回退到原始流式处理
+            async for chunk in self.handle_tool_call_stream(tool_name, arguments, session_id):
+                yield chunk
+            return
+        
+        # 如果没有提供session_id，自动创建一个
+        if session_id is None:
+            session_id = self.start_streaming_session()
+        
+        try:
+            # 获取原始流式生成器
+            original_stream = self.handle_tool_call_stream(tool_name, arguments, session_id)
+            
+            # 使用OpenAI格式包装器包装流式输出
+            async for openai_chunk in self._openai_stream_wrapper.wrap_tool_call_stream(
+                tool_name, arguments, original_stream, session_id
+            ):
+                # 检查是否应该停止
+                if self.is_streaming_stopped(session_id):
+                    self.logger.info(f"OpenAI streaming stopped for session {session_id}")
+                    break
+                yield openai_chunk
+                
+        except Exception as e:
+            self.logger.error(f"Error in OpenAI streaming for tool {tool_name}: {e}")
+            # 发送错误格式的OpenAI响应
+            formatter = OpenAIStreamFormatter(self._openai_stream_wrapper.model_name, session_id)
+            error_chunk = formatter.create_error_chunk(str(e))
+            yield error_chunk.to_sse_data()
+        finally:
+            # 清理会话
+            if session_id:
+                self.cleanup_streaming_session(session_id)
+    
+    async def handle_simple_response_openai(
+        self, 
+        content: Any, 
+        session_id: str = None
+    ) -> AsyncGenerator[str, None]:
+        """将简单响应包装为OpenAI格式的流式输出
+        
+        Args:
+            content: 响应内容
+            session_id: 会话ID
+            
+        Yields:
+            OpenAI格式的SSE数据字符串
+        """
+        if not self._enable_openai_format:
+            # 如果未启用OpenAI格式，直接返回内容
+            yield str(content)
+            return
+        
+        try:
+            async for openai_chunk in self._openai_stream_wrapper.wrap_simple_response(content, session_id):
+                yield openai_chunk
+        except Exception as e:
+            self.logger.error(f"Error in OpenAI simple response streaming: {e}")
+            formatter = OpenAIStreamFormatter(self._openai_stream_wrapper.model_name, session_id)
+            error_chunk = formatter.create_error_chunk(str(e))
+            yield error_chunk.to_sse_data()
+
+    def _notify_config_update(self, old_config: Dict[str, Any], new_config: Dict[str, Any]) -> None:
+        """通知所有注册的回调函数配置已更新"""
+        for callback in self._config_update_callbacks:
+            try:
+                callback(old_config, new_config)
+            except Exception as e:
+                self.logger.error(f"Error in config update callback {callback.__name__}: {e}")
+
     def add_tool(self, tool: dict) -> None:
         """添加工具（去重：同名工具将被替换而不是重复添加）"""
         for idx, existing in enumerate(self.tools):
@@ -532,6 +654,13 @@ class EnhancedMCPServer(BaseMCPServer):
         self.add_resource(resource)
         self._resource_handlers[uri] = handler
 
+    async def initialize(self) -> None:
+        """初始化服务器"""
+        # 触发装饰器注册（通过访问setup_tools属性）
+        if hasattr(self, 'setup_tools'):
+            _ = self.setup_tools
+        self.logger.info(f"EnhancedMCPServer '{self.name}' initialized")
+
     async def handle_tool_call(self, tool_name: str, arguments: Dict[str, Any]) -> Any:
         """自动分发工具调用到注册的处理函数"""
         # 首先检查普通工具处理器
@@ -660,6 +789,12 @@ class EnhancedMCPServer(BaseMCPServer):
 
     def get_server_parameters(self) -> List[ServerParameter]:
         """获取服务器参数定义，支持装饰器配置"""
+        # 触发装饰器注册（如果有 setup_tools 或 setup_server_params 属性）
+        if hasattr(self, 'setup_tools'):
+            _ = self.setup_tools
+        if hasattr(self, 'setup_server_params'):
+            _ = self.setup_server_params
+        
         # 合并装饰器配置的参数和子类定义的参数
         # 检查 decorators 是否已初始化
         decorator_params = []
@@ -687,23 +822,19 @@ class EnhancedMCPServer(BaseMCPServer):
 
         return unique_params
 
-    # 提供装饰器访问
-    @property
-    def tool(self):
+    # 提供装饰器直接访问
+    def tool(self, description: str = None, chunk_size: int = 100, role = None):
         """工具装饰器"""
-        return self.decorators.tool
+        return self.decorators.tool(description=description, chunk_size=chunk_size, role=role)
 
-    @property
-    def streaming_tool(self):
+    def streaming_tool(self, description: str = None, chunk_size: int = 50, role = None):
         """流式工具装饰器"""
-        return self.decorators.streaming_tool
+        return self.decorators.streaming_tool(description=description, chunk_size=chunk_size, role=role)
 
-    @property
-    def resource(self):
+    def resource(self, uri: str, name: str = None, description: str = None, mime_type: str = 'text/plain'):
         """资源装饰器"""
-        return self.decorators.resource
+        return self.decorators.resource(uri=uri, name=name, description=description, mime_type=mime_type)
 
-    @property
-    def server_param(self):
+    def server_param(self, name: str):
         """服务器参数装饰器"""
-        return self.decorators.server_param
+        return self.decorators.server_param(name=name)
