@@ -3,11 +3,13 @@ MCP HTTP 服务器模块
 """
 
 from .http_server import MCPHTTPServer
+from .stdio_server import MCPStdioServer
 from .handlers import MCPRequestHandler, APIHandler, ServerConfigHandler, OptionsHandler
 from .middleware import cors_middleware, error_middleware, logging_middleware
 
 __all__ = [
     'MCPHTTPServer',
+    'MCPStdioServer',
     'MCPRequestHandler',
     'APIHandler',
     'ServerConfigHandler',
